==> jc-1.4.0.tar.gz: gnu/java/rmi/server/RMIIncomingThread.h <==
// public class gnu.java.rmi.server.RMIIncomingThread

// class file dependencies
// @dep_class 18b2b0f8c6a22df7 gnu_java_rmi_server_RMIIncomingThread
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_gnu_java_rmi_server_RMIIncomingThread_H_
#define _JC_gnu_java_rmi_server_RMIIncomingThread_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Runnable$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIIncomingThread$sub_refs	_jc_gnu_java_rmi_server_RMIIncomingThread$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIIncomingThread$sub_nonrefs	_jc_gnu_java_rmi_server_RMIIncomingThread$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIIncomingThread$refs	_jc_gnu_java_rmi_server_RMIIncomingThread$refs;
typedef struct _jc_gnu_java_rmi_server_RMIIncomingThread$nonrefs	_jc_gnu_java_rmi_server_RMIIncomingThread$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIIncomingThread$object	_jc_gnu_java_rmi_server_RMIIncomingThread$object;

typedef const struct _jc_gnu_java_rmi_server_RMIIncomingThread$vmethods	_jc_gnu_java_rmi_server_RMIIncomingThread$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIIncomingThread$vtable	_jc_gnu_java_rmi_server_RMIIncomingThread$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIIncomingThread$vtype	_jc_gnu_java_rmi_server_RMIIncomingThread$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIIncomingThread$method$_init$5acc5c3a2adc1d01(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_rmi_server_RMIIncomingThread$method$getClientHost$724d6b00474d82a0(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *);
extern void _jc_gnu_java_rmi_server_RMIIncomingThread$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_rmi_server_RMIIncomingThread$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_RMIIncomingThread$method_info$getClientHost$724d6b00474d82a0;
extern _jc_method _jc_gnu_java_rmi_server_RMIIncomingThread$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_gnu_java_rmi_server_RMIIncomingThread$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIIncomingThread$vmethods {
	struct _jc_java_lang_String$object	*(*getClientHost$724d6b00474d82a0)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *);
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIIncomingThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_gnu_java_rmi_server_RMIIncomingThread$vmethods	gnu_java_rmi_server_RMIIncomingThread;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIIncomingThread$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIIncomingThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIIncomingThread$sub_refs {
	struct _jc_java_lang_String$object	*clientHost;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIIncomingThread$refs {
    _jc_gnu_java_rmi_server_RMIIncomingThread$sub_refs	gnu_java_rmi_server_RMIIncomingThread;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIIncomingThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIIncomingThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_gnu_java_rmi_server_RMIIncomingThread$sub_nonrefs	gnu_java_rmi_server_RMIIncomingThread;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIIncomingThread$object {
	_jc_gnu_java_rmi_server_RMIIncomingThread$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIIncomingThread$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIIncomingThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIIncomingThread$vtype _jc_gnu_java_rmi_server_RMIIncomingThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIIncomingThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIIncomingThread$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIIncomingThread_H_ */

==> jc-1.4.6.tar.gz: gnu/java/rmi/server/RMIIncomingThread.h <==
// public class gnu.java.rmi.server.RMIIncomingThread

// class file dependencies
// @dep_class 18b2b0f8c6a22df7 gnu_java_rmi_server_RMIIncomingThread
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e33d4feabbc3f15 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_gnu_java_rmi_server_RMIIncomingThread_H_
#define _JC_gnu_java_rmi_server_RMIIncomingThread_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Runnable$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIIncomingThread$sub_refs	_jc_gnu_java_rmi_server_RMIIncomingThread$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIIncomingThread$sub_nonrefs	_jc_gnu_java_rmi_server_RMIIncomingThread$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIIncomingThread$refs	_jc_gnu_java_rmi_server_RMIIncomingThread$refs;
typedef struct _jc_gnu_java_rmi_server_RMIIncomingThread$nonrefs	_jc_gnu_java_rmi_server_RMIIncomingThread$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIIncomingThread$object	_jc_gnu_java_rmi_server_RMIIncomingThread$object;

typedef const struct _jc_gnu_java_rmi_server_RMIIncomingThread$vmethods	_jc_gnu_java_rmi_server_RMIIncomingThread$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIIncomingThread$vtable	_jc_gnu_java_rmi_server_RMIIncomingThread$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIIncomingThread$vtype	_jc_gnu_java_rmi_server_RMIIncomingThread$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIIncomingThread$method$_init$5acc5c3a2adc1d01(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_java_rmi_server_RMIIncomingThread$method$getClientHost$724d6b00474d82a0(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_rmi_server_RMIIncomingThread$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_rmi_server_RMIIncomingThread$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_RMIIncomingThread$method_info$getClientHost$724d6b00474d82a0;
extern _jc_method _jc_gnu_java_rmi_server_RMIIncomingThread$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_gnu_java_rmi_server_RMIIncomingThread$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIIncomingThread$vmethods {
	struct _jc_java_lang_String$object	*(*getClientHost$724d6b00474d82a0)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIIncomingThread$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIIncomingThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_gnu_java_rmi_server_RMIIncomingThread$vmethods	gnu_java_rmi_server_RMIIncomingThread;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIIncomingThread$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIIncomingThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIIncomingThread$sub_refs {
	struct _jc_java_lang_String$object	*clientHost;
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIIncomingThread$refs {
    _jc_gnu_java_rmi_server_RMIIncomingThread$sub_refs	gnu_java_rmi_server_RMIIncomingThread;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIIncomingThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIIncomingThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_gnu_java_rmi_server_RMIIncomingThread$sub_nonrefs	gnu_java_rmi_server_RMIIncomingThread;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIIncomingThread$object {
	_jc_gnu_java_rmi_server_RMIIncomingThread$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIIncomingThread$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIIncomingThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIIncomingThread$vtype _jc_gnu_java_rmi_server_RMIIncomingThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIIncomingThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIIncomingThread$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIIncomingThread_H_ */
